@@ -175,7 +175,6 @@ gepub_doc_initable_init (GInitable     *initable,
 {
     GepubDoc *doc = GEPUB_DOC (initable);
     gchar *file;
-    gsize bufsize = 0;
     gint i = 0, len;
 
     g_assert (doc->path != NULL);
@@ -251,13 +250,13 @@ gepub_doc_fill_resources (GepubDoc *doc)
             continue;
         }
 
-        id = xmlGetProp (item, "id");
-        tmpuri = xmlGetProp (item, "href");
+        id = gepub_utils_get_prop (item, "id");
+        tmpuri = gepub_utils_get_prop (item, "href");
         uri = g_strdup_printf ("%s%s", doc->content_base, tmpuri);
         g_free (tmpuri);
 
         res = g_malloc (sizeof (GepubResource));
-        res->mime = xmlGetProp (item, "media-type");
+        res->mime = gepub_utils_get_prop (item, "media-type");
         res->uri = uri;
         g_hash_table_insert (doc->resources, id, res);
         item = item->next;
@@ -290,7 +289,7 @@ gepub_doc_fill_spine (GepubDoc *doc)
             continue;
         }
 
-        id = xmlGetProp (item, "idref");
+        id = gepub_utils_get_prop (item, "idref");
 
         spine = g_list_prepend (spine, id);
         item = item->next;
@@ -311,6 +310,8 @@ gepub_doc_fill_spine (GepubDoc *doc)
 GBytes *
 gepub_doc_get_content (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+
     return doc->content;
 }
 
@@ -333,6 +334,9 @@ gepub_doc_get_metadata (GepubDoc *doc, const gchar *mdata)
     const char *data;
     gsize size;
 
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (mdata != NULL, NULL);
+
     data = g_bytes_get_data (doc->content, &size);
     xdoc = xmlRecoverMemory (data, size);
     root_element = xmlDocGetRootElement (xdoc);
@@ -340,7 +344,7 @@ gepub_doc_get_metadata (GepubDoc *doc, const gchar *mdata)
     mdata_node = gepub_utils_get_element_by_tag (mnode, mdata);
 
     text = xmlNodeGetContent (mdata_node);
-    ret = g_strdup (text);
+    ret = g_strdup ((const char *) text);
     xmlFree (text);
 
     xmlFreeDoc (xdoc);
@@ -357,6 +361,8 @@ gepub_doc_get_metadata (GepubDoc *doc, const gchar *mdata)
 GHashTable *
 gepub_doc_get_resources (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+
     return doc->resources;
 }
 
@@ -370,7 +376,12 @@ gepub_doc_get_resources (GepubDoc *doc)
 GBytes *
 gepub_doc_get_resource_by_id (GepubDoc *doc, const gchar *id)
 {
-    GepubResource *gres = g_hash_table_lookup (doc->resources, id);
+    GepubResource *gres;
+
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (id != NULL, NULL);
+
+    gres = g_hash_table_lookup (doc->resources, id);
     if (!gres) {
         // not found
         return NULL;
@@ -389,6 +400,9 @@ gepub_doc_get_resource_by_id (GepubDoc *doc, const gchar *id)
 GBytes *
 gepub_doc_get_resource (GepubDoc *doc, const gchar *path)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (path != NULL, NULL);
+
     return gepub_archive_read_entry (doc->archive, path);
 }
 
@@ -404,6 +418,7 @@ gepub_doc_get_resource_mime_by_id (GepubDoc *doc, const gchar *id)
 {
     GepubResource *gres;
 
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
     g_return_val_if_fail (id != NULL, NULL);
 
     gres = g_hash_table_lookup (doc->resources, id);
@@ -426,7 +441,12 @@ gchar *
 gepub_doc_get_resource_mime (GepubDoc *doc, const gchar *path)
 {
     GepubResource *gres;
-    GList *keys = g_hash_table_get_keys (doc->resources);
+    GList *keys;
+
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (path != NULL, NULL);
+
+    keys = g_hash_table_get_keys (doc->resources);
 
     while (keys) {
         gres = ((GepubResource*)g_hash_table_lookup (doc->resources, keys->data));
@@ -450,6 +470,9 @@ gepub_doc_get_resource_mime (GepubDoc *doc, const gchar *path)
 gchar *
 gepub_doc_get_current_mime (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (doc->page != NULL, NULL);
+
     return gepub_doc_get_resource_mime_by_id (doc, doc->page->data);
 }
 
@@ -462,6 +485,9 @@ gepub_doc_get_current_mime (GepubDoc *doc)
 GBytes *
 gepub_doc_get_current (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (doc->page != NULL, NULL);
+
     return gepub_doc_get_resource_by_id (doc, doc->page->data);
 }
 
@@ -470,18 +496,23 @@ gepub_doc_get_current (GepubDoc *doc)
  * @doc: a #GepubDoc
  *
  * Returns: (transfer full): the current chapter
- * data, with resource uris renamed so they have the epub:// prefix and all
+ * data, with resource uris renamed so they have the epub:/// prefix and all
  * are relative to the root file
  */
 GBytes *
 gepub_doc_get_current_with_epub_uris (GepubDoc *doc)
 {
-    GBytes *content = gepub_doc_get_current (doc);
-    gchar *path = gepub_doc_get_current_path (doc);
-    // getting the basepath of the current xhtml loaded
-    gchar *base = g_path_get_dirname (path);
+    GBytes *content, *replaced;
+    gchar *path, *base;
 
-    GBytes *replaced = gepub_utils_replace_resources (content, base);
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+
+    content = gepub_doc_get_current (doc);
+    path = gepub_doc_get_current_path (doc);
+    // getting the basepath of the current xhtml loaded
+    base = g_path_get_dirname (path);
+
+    replaced = gepub_utils_replace_resources (content, base);
 
     g_free (path);
     g_bytes_unref (content);
@@ -501,11 +532,13 @@ gepub_doc_get_text (GepubDoc *doc)
     xmlDoc *xdoc = NULL;
     xmlNode *root_element = NULL;
     GBytes *current;
-    const guchar *data;
+    const gchar *data;
     gsize size;
 
     GList *texts = NULL;
 
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+
     current = gepub_doc_get_current (doc);
     if (!current) {
         return NULL;
@@ -534,13 +567,16 @@ gepub_doc_get_text_by_id (GepubDoc *doc, const gchar *id)
     xmlDoc *xdoc = NULL;
     xmlNode *root_element = NULL;
     gsize size;
-    const guchar *res;
+    const gchar *res;
     GBytes *contents;
 
     GList *texts = NULL;
 
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (id != NULL, NULL);
+
     contents = gepub_doc_get_resource_by_id (doc, id);
-    if (!res) {
+    if (!contents) {
         return NULL;
     }
 
@@ -577,6 +613,9 @@ gepub_doc_set_page_internal (GepubDoc *doc,
 gboolean
 gepub_doc_go_next (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), FALSE);
+    g_return_val_if_fail (doc->page != NULL, FALSE);
+
     return gepub_doc_set_page_internal (doc, doc->page->next);
 }
 
@@ -589,6 +628,9 @@ gepub_doc_go_next (GepubDoc *doc)
 gboolean
 gepub_doc_go_prev (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), FALSE);
+    g_return_val_if_fail (doc->page != NULL, FALSE);
+
     return gepub_doc_set_page_internal (doc, doc->page->prev);
 }
 
@@ -601,6 +643,8 @@ gepub_doc_go_prev (GepubDoc *doc)
 int
 gepub_doc_get_n_pages (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), 0);
+
     return g_list_length (doc->spine);
 }
 
@@ -613,6 +657,10 @@ gepub_doc_get_n_pages (GepubDoc *doc)
 int
 gepub_doc_get_page (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), 0);
+    g_return_val_if_fail (doc->spine != NULL, 0);
+    g_return_val_if_fail (doc->page != NULL, 0);
+
     return g_list_position (doc->spine, doc->page);
 }
 
@@ -629,6 +677,8 @@ gepub_doc_set_page (GepubDoc *doc,
 {
     GList *page;
 
+    g_return_if_fail (GEPUB_IS_DOC (doc));
+
     g_return_if_fail (index >= 0 && index <= gepub_doc_get_n_pages (doc));
 
     page = g_list_nth (doc->spine, index);
@@ -649,18 +699,17 @@ gepub_doc_get_cover (GepubDoc *doc)
     xmlNode *root_element = NULL;
     xmlNode *mnode = NULL;
     gchar *ret;
-    xmlChar *text;
     const char *data;
     gsize size;
 
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (doc->content != NULL, NULL);
+
     data = g_bytes_get_data (doc->content, &size);
     xdoc = xmlRecoverMemory (data, size);
     root_element = xmlDocGetRootElement (xdoc);
     mnode = gepub_utils_get_element_by_attr (root_element, "name", "cover");
-    text = xmlGetProp(mnode, "content");
-
-    ret = g_strdup (text);
-    xmlFree (text);
+    ret = gepub_utils_get_prop (mnode, "content");
 
     xmlFreeDoc (xdoc);
 
@@ -677,7 +726,12 @@ gepub_doc_get_cover (GepubDoc *doc)
 gchar *
 gepub_doc_get_resource_path (GepubDoc *doc, const gchar *id)
 {
-    GepubResource *gres = g_hash_table_lookup (doc->resources, id);
+    GepubResource *gres;
+
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (id != NULL, NULL);
+
+    gres = g_hash_table_lookup (doc->resources, id);
     if (!gres) {
         // not found
         return NULL;
@@ -695,6 +749,9 @@ gepub_doc_get_resource_path (GepubDoc *doc, const gchar *id)
 gchar *
 gepub_doc_get_current_path (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (doc->page != NULL, NULL);
+
     return gepub_doc_get_resource_path (doc, doc->page->data);
 }
 
@@ -708,5 +765,8 @@ gepub_doc_get_current_path (GepubDoc *doc)
 const gchar *
 gepub_doc_get_current_id (GepubDoc *doc)
 {
+    g_return_val_if_fail (GEPUB_IS_DOC (doc), NULL);
+    g_return_val_if_fail (doc->page != NULL, NULL);
+
     return doc->page->data;
 }
